﻿##### Scriptinfo ##################################################################################
# Scriptreihe:      Show-EncryptionSymmetric
# Datum:            2017-09-27
# Version:          V1.00
# Programmierer:    Stephan Walther
###################################################################################################

# Funktionen
    function Set-Key {
        param([string]$string)

        $length = $string.length
        $pad = 32-$length
        if (($length -lt 6) -or ($length -gt 32)) {Throw "Key muss zwischen 16 und 32 Zeichen lang sein!"}
        $encoding = New-Object System.Text.ASCIIEncoding
        $bytes = $encoding.GetBytes($string + "0" * $pad)
        return $bytes
    }

    function Set-EncryptedData {
        param($key,[string]$plainText)

        $securestring = new-object System.Security.SecureString
        $chars = $plainText.toCharArray()
        foreach ($char in $chars) {$secureString.AppendChar($char)}
        $encryptedData = ConvertFrom-SecureString -SecureString $secureString -Key $key
        return $encryptedData
    }

    function Get-EncryptedData {
        param($key,$data)

        $ErrorActionPreference = 'silentlycontinue'
        $data | ConvertTo-SecureString -key $key |
        ForEach-Object {[Runtime.InteropServices.Marshal]::PtrToStringAuto([Runtime.InteropServices.Marshal]::SecureStringToBSTR($_))}

        $ErrorActionPreference = 'continue'
    }

# Verwendung
    $PlainText     = "Geheimer Text"
    $key           = Set-Key -string (Read-Host -Prompt 'Passwort')
    $EncryptedText = Set-EncryptedData -key $key -plainText $plaintext
    $EncryptedText

    $DecryptedText = Get-EncryptedData -data $EncryptedText -key $key 
    $DecryptedText

# SIG # Begin signature block
# MIII4QYJKoZIhvcNAQcCoIII0jCCCM4CAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUW1DSagCK0BGvAdXnzdW6ysZS
# VPmgggY/MIIGOzCCBSOgAwIBAgITGwAAAOBAvnzebcAjSAABAAAA4DANBgkqhkiG
# 9w0BAQsFADBUMRMwEQYKCZImiZPyLGQBGRYDaXRzMRIwEAYKCZImiZPyLGQBGRYC
# d3MxKTAnBgNVBAMTIFdTLUlUUy1aZXJ0aWZpemllcnVuZ3NzdGVsbGUtQ0ExMB4X
# DTE3MDUxMDA1NDI0OVoXDTE5MDUxMDA1NTI0OVowdTETMBEGCgmSJomT8ixkARkW
# A2l0czESMBAGCgmSJomT8ixkARkWAndzMQswCQYDVQQLEwJXUzERMA8GA1UECxMI
# QmVudXR6ZXIxDzANBgNVBAsTBldTLUlUUzEZMBcGA1UEAxMQV2FsdGhlciwgU3Rl
# cGhhbjCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAKqnKBq0nJLvqGwO
# aJkLU2174/KhLd4ykJZ2BgG4wse7s3ALM7dH1vxNmeKIoB09yk9nYZzDeRjZ7w7a
# WKgko8zvNHJCleQNtG6AReOoMIRuYyrbUmbKlmICn9V/ENUNQ6s1tiqnAIChb0J2
# 05GMaBYG+IFS+uLDzlTIsoaEKZjV3htgBEVQt6BYIdbsZ913ZUcpGWhQsCXKairT
# wB8pqPTaBCA5HJHyfAwxa+w2ERhF5q0r/xp9dEkemFjy0Xo9aQWUw3WPy8l3pTyp
# I2w/yDFqLfZu5z1QjWrcNA9VirSiM9PkOPXQb9riChc4PfFd90+JjeVhOlj3y0qb
# InQsfUMCAwEAAaOCAuMwggLfMA4GA1UdDwEB/wQEAwIHgDA8BgkrBgEEAYI3FQcE
# LzAtBiUrBgEEAYI3FQiIoH6B98FWhLmPAobjm2SE8KUnMYPz1QqE8ow3AgFkAgEC
# MB0GA1UdDgQWBBT1lyML2Qw04hBbAlX5PeqiA5IBQjAfBgNVHSMEGDAWgBS1Nrmv
# a6rveo5pQqKi2+u+kQ59cTCCASAGA1UdHwSCARcwggETMIIBD6CCAQugggEHhoHE
# bGRhcDovLy9DTj1XUy1JVFMtWmVydGlmaXppZXJ1bmdzc3RlbGxlLUNBMSgxKSxD
# Tj1XUy1DQTEsQ049Q0RQLENOPVB1YmxpYyUyMEtleSUyMFNlcnZpY2VzLENOPVNl
# cnZpY2VzLENOPUNvbmZpZ3VyYXRpb24sREM9d3MsREM9aXRzP2NlcnRpZmljYXRl
# UmV2b2NhdGlvbkxpc3Q/YmFzZT9vYmplY3RDbGFzcz1jUkxEaXN0cmlidXRpb25Q
# b2ludIY+aHR0cDovL2NybC53cy5pdHMvY3JsZC9XUy1JVFMtWmVydGlmaXppZXJ1
# bmdzc3RlbGxlLUNBMSgxKS5jcmwwgc0GCCsGAQUFBwEBBIHAMIG9MIG6BggrBgEF
# BQcwAoaBrWxkYXA6Ly8vQ049V1MtSVRTLVplcnRpZml6aWVydW5nc3N0ZWxsZS1D
# QTEsQ049QUlBLENOPVB1YmxpYyUyMEtleSUyMFNlcnZpY2VzLENOPVNlcnZpY2Vz
# LENOPUNvbmZpZ3VyYXRpb24sREM9d3MsREM9aXRzP2NBQ2VydGlmaWNhdGU/YmFz
# ZT9vYmplY3RDbGFzcz1jZXJ0aWZpY2F0aW9uQXV0aG9yaXR5MBMGA1UdJQQMMAoG
# CCsGAQUFBwMDMBsGCSsGAQQBgjcVCgQOMAwwCgYIKwYBBQUHAwMwKQYDVR0RBCIw
# IKAeBgorBgEEAYI3FAIDoBAMDnN0ZXBoYW5Ad3MuaXRzMA0GCSqGSIb3DQEBCwUA
# A4IBAQBjyTnnRXeyMEPW8SziBVFJcsX0K3XLCXz7PEl6sVuiWTHY3n9IOwJJ2sqF
# 3Sea0bpWrDFnJQtB+S4FXW6A/bVvuPlGMBtZ7T9DowowAQAmWvC/OJeeHGz2xyjh
# fDYAmMi3DXrVIEv+yWHsrh6CSt0KiHjMOh/Kk092AmyyPSRZpqmabzcoY7fI6xff
# ckOvS+Q3233ytXfS2YMuNKL8EuGaUhGj8Smb3grUtNW0kyJmL2wTgyWdUerbGpC3
# Ss7iv53hJXSoe8Rmo8spntb/5e+zt6q0ThqI4TN6sm9Gqgg8QcfzGc0XvW7V2GKU
# LT75dOMzV86lFZo+rvq1SaZb2GRcMYICDDCCAggCAQEwazBUMRMwEQYKCZImiZPy
# LGQBGRYDaXRzMRIwEAYKCZImiZPyLGQBGRYCd3MxKTAnBgNVBAMTIFdTLUlUUy1a
# ZXJ0aWZpemllcnVuZ3NzdGVsbGUtQ0ExAhMbAAAA4EC+fN5twCNIAAEAAADgMAkG
# BSsOAwIaBQCgeDAYBgorBgEEAYI3AgEMMQowCKACgAChAoAAMBkGCSqGSIb3DQEJ
# AzEMBgorBgEEAYI3AgEEMBwGCisGAQQBgjcCAQsxDjAMBgorBgEEAYI3AgEVMCMG
# CSqGSIb3DQEJBDEWBBTyZNG5tLGXhYXYlBYZdOjrQeZFUjANBgkqhkiG9w0BAQEF
# AASCAQAAjSdxiTo74QjpHVdvsznmospKOaBH0FFwGSJrKkYlxbw9W8cZYDj1pr0L
# 0XobqCGIUKx99BwHZPjpjXPb1VUaqJ7cZBTU6EwKV+d1RbjFYs7I5Lo3y4d+30g3
# Dvg4BmAUz0Mcj/87bykeQ/1t5AzD56IvTWmXi/CvygdhmeOOeJyFsD1HTDEpKlRX
# sBRvuV9w+kSe7R3evqob4M4CKtdTgMrhK2jIsjHm+9Ba5yV+cXFQxNiPsUcxEit3
# PyN+6Q0RjJ1Kvn1kHyiZcr541g8BrBvjMt8g+zFiySDBu2Z6WQepRAEGP/IAA9vE
# l/uoK2sYH7Lk67XJCgoXqoHyHa/o
# SIG # End signature block
